##  Applicable Use Cases
  * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs."): Include platforms early on to get C-level buy-in for your modernization use case.
